==> connectagram_1.2.10.orig.tar.gz: connectagram-1.2.10/translations/connectagram_tr.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="tr">
<context>
    <name>ChainPattern</name>
    <message>
        <source>Chain</source>
        <translation>Zincir</translation>
    </message>
</context>
<context>
    <name>Clock</name>
    <message>
        <source>Loading</source>
        <translation>Yükleniyor</translation>
    </message>
    <message>
        <source>Paused</source>
        <translation>Duraklatıldı</translation>
    </message>
</context>
<context>
    <name>Definitions</name>
    <message>
        <source>Definitions</source>
        <translation>Anlamlar</translation>
    </message>
    <message>
        <source>Downloading definition...</source>
        <translation>Anlam indiriliyor...</translation>
    </message>
    <message>
        <source>Unsolved word</source>
        <translation>Çözülmemiş kelime</translation>
    </message>
</context>
<context>
    <name>Dictionary</name>
    <message>
        <source>Definition from Wiktionary, the free dictionary</source>
        <translation>Wiktionary, ücretsiz sözlük&apos;ten anlam</translation>
    </message>
    <message>
        <source>No definition found</source>
        <translation>Anlam bulunamadı</translation>
    </message>
    <message>
        <source>Unable to connect to Wiktionary</source>
        <translation>Wiktionary&apos;ye bağlanılamadı</translation>
    </message>
</context>
<context>
    <name>FencePattern</name>
    <message>
        <source>Fence</source>
        <translation>Çit</translation>
    </message>
</context>
<context>
    <name>LocaleDialog</name>
    <message>
        <source>Select application language:</source>
        <translation>Uygulama dilini seçin:</translation>
    </message>
    <message>
        <source>&lt;System Language&gt;</source>
        <translation>&lt;Sistem Dili&gt;</translation>
    </message>
    <message>
        <source>Note</source>
        <translation>Not</translation>
    </message>
    <message>
        <source>Please restart this application for the change in language to take effect.</source>
        <translation>Dil değişikliğinin etkin olması için lütfen bu uygulamayı yeniden başlatın.</translation>
    </message>
</context>
<context>
    <name>NewGameDialog</name>
    <message>
        <source>New Game</source>
        <translation>Yeni Oyun</translation>
    </message>
    <message>
        <source>Low</source>
        <translation>Az</translation>
    </message>
    <message>
        <source>Medium</source>
        <translation>Orta</translation>
    </message>
    <message>
        <source>High</source>
        <translation>Çok</translation>
    </message>
    <message>
        <source>Very High</source>
        <translation>Daha Çok</translation>
    </message>
    <message>
        <source>Language:</source>
        <translation>Dil:</translation>
    </message>
    <message>
        <source>Word Length:</source>
        <translation>Kelime Uzunluğu:</translation>
    </message>
    <message>
        <source>Amount of Words:</source>
        <translation>Kelime Miktarı:</translation>
    </message>
    <message numerus="yes">
        <source>%n letter(s)</source>
        <translation>
            <numerusform>%n kelime</numerusform>
        </translation>
    </message>
</context>
<context>
    <name>RingsPattern</name>
    <message>
        <source>Rings</source>
        <translation>Halka</translation>
    </message>
</context>
<context>
    <name>ScoreBoard</name>
    <message>
        <source>Scores</source>
        <translation>Skorlar</translation>
    </message>
    <message>
        <source>Score</source>
        <translation>Skor</translation>
    </message>
    <message>
        <source>Time</source>
        <translation>Süre</translation>
    </message>
    <message>
        <source>Words</source>
        <translation>Kelime</translation>
    </message>
    <message>
        <source>Length</source>
        <translation>Uzunluk</translation>
    </message>
</context>
<context>
    <name>StairsPattern</name>
    <message>
        <source>Stairs</source>
        <translation>Merdiven</translation>
    </message>
</context>
<context>
    <name>TwistyPattern</name>
    <message>
        <source>Twisty</source>
        <translation>Kıvrımlı</translation>
    </message>
</context>
<context>
    <name>WavePattern</name>
    <message>
        <source>Wave</source>
        <translation>Dalga</translation>
    </message>
</context>
<context>
    <name>Window</name>
    <message>
        <source>Success</source>
        <translation>Başarılı</translation>
    </message>
    <message>
        <source>Loading</source>
        <translation>Yükleniyor</translation>
    </message>
    <message>
        <source>Paused</source>
        <translation>Duraklatıldı</translation>
    </message>
    <message>
        <source>Definitions</source>
        <translation>Anlamlar</translation>
    </message>
    <message>
        <source>Hint</source>
        <translation>İpucu</translation>
    </message>
    <message>
        <source>&amp;Game</source>
        <translation>&amp;Oyun</translation>
    </message>
    <message>
        <source>&amp;New</source>
        <translation>&amp;Yeni</translation>
    </message>
    <message>
        <source>&amp;Choose...</source>
        <translation>S&amp;eç...</translation>
    </message>
    <message>
        <source>&amp;Details</source>
        <translation>&amp;Ayrıntılar</translation>
    </message>
    <message>
        <source>&amp;Pause</source>
        <translation>&amp;Duraklat</translation>
    </message>
    <message>
        <source>P</source>
        <translation>P</translation>
    </message>
    <message>
        <source>&amp;Hint</source>
        <translation>&amp;İpucu</translation>
    </message>
    <message>
        <source>H</source>
        <translation>H</translation>
    </message>
    <message>
        <source>D&amp;efinitions</source>
        <translation>A&amp;nlamlar</translation>
    </message>
    <message>
        <source>D</source>
        <translation>D</translation>
    </message>
    <message>
        <source>&amp;Scores</source>
        <translation>&amp;Skorlar</translation>
    </message>
    <message>
        <source>&amp;Quit</source>
        <translation>&amp;Çık</translation>
    </message>
    <message>
        <source>&amp;Settings</source>
        <translation>&amp;Ayarlar</translation>
    </message>
    <message>
        <source>Application &amp;Language...</source>
        <translation>Uygulama &amp;Dili</translation>
    </message>
    <message>
        <source>&amp;Help</source>
        <translation>&amp;Yardım</translation>
    </message>
    <message>
        <source>&amp;About</source>
        <translation>&amp;Hakkında</translation>
    </message>
    <message>
        <source>About &amp;Qt</source>
        <translation>&amp;Qt Hakkında</translation>
    </message>
    <message>
        <source>Choose Game</source>
        <translation>Oyun Seç</translation>
    </message>
    <message>
        <source>Game Number:</source>
        <translation>Oyun Numarası:</translation>
    </message>
    <message>
        <source>Sorry</source>
        <translation>Üzgünüm</translation>
    </message>
    <message>
        <source>Unable to start requested game.</source>
        <translation>Seçilen oyun başlatılamıyor.</translation>
    </message>
    <message>
        <source>About</source>
        <translation>Hakkında</translation>
    </message>
    <message>
        <source>Connectagram</source>
        <translation>Connectagram</translation>
    </message>
    <message>
        <source>A word unscrambling game</source>
        <translation>Bir kelime düzenleme oyunu</translation>
    </message>
    <message>
        <source>Copyright &amp;copy; 2009-%1 by Graeme Gott</source>
        <translation>Telif hakları saklıdır &amp;copy; 2009-%1 Graeme Gott</translation>
    </message>
    <message>
        <source>Released under the &lt;a href=&quot;http://www.gnu.org/licenses/gpl.html&quot;&gt;GPL 3&lt;/a&gt; license</source>
        <translation>&lt;a href=&quot;http://www.gnu.org/licenses/gpl.html&quot;&gt;GPL 3&lt;/a&gt; lisansı altında yayınlanmıştır</translation>
    </message>
    <message>
        <source>Definitions are from &lt;a href=&quot;http://wiktionary.org/&quot;&gt;Wiktionary&lt;/a&gt;</source>
        <translation>Anlamlar &lt;a href=&quot;http://wiktionary.org/&quot;&gt;Wiktionary&lt;/a&gt;&apos;dendir.</translation>
    </message>
    <message>
        <source>Details</source>
        <translation>Ayrıntılar</translation>
    </message>
    <message>
        <source>Pattern:</source>
        <translation>Kalıp:</translation>
    </message>
    <message>
        <source>&amp;Resume</source>
        <translation>&amp;Devam Ettir</translation>
    </message>
</context>
</TS>

==> connectagram_1.3.1.orig.tar.gz: connectagram-1.3.1/translations/connectagram_tr.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="tr">
<context>
    <name>ChainPattern</name>
    <message>
        <source>Chain</source>
        <translation>Zincir</translation>
    </message>
</context>
<context>
    <name>Clock</name>
    <message>
        <source>Loading</source>
        <translation>Yükleniyor</translation>
    </message>
    <message>
        <source>Paused</source>
        <translation>Duraklatıldı</translation>
    </message>
</context>
<context>
    <name>FencePattern</name>
    <message>
        <source>Fence</source>
        <translation>Çit</translation>
    </message>
</context>
<context>
    <name>LocaleDialog</name>
    <message>
        <source>Select application language:</source>
        <translation>Uygulama dilini seçin:</translation>
    </message>
    <message>
        <source>&lt;System Language&gt;</source>
        <translation>&lt;Sistem Dili&gt;</translation>
    </message>
    <message>
        <source>Note</source>
        <translation>Not</translation>
    </message>
    <message>
        <source>Please restart this application for the change in language to take effect.</source>
        <translation>Dil değişikliğinin etkin olması için lütfen bu uygulamayı yeniden başlatın.</translation>
    </message>
</context>
<context>
    <name>NewGameDialog</name>
    <message>
        <source>New Game</source>
        <translation>Yeni Oyun</translation>
    </message>
    <message>
        <source>Low</source>
        <translation>Az</translation>
    </message>
    <message>
        <source>Medium</source>
        <translation>Orta</translation>
    </message>
    <message>
        <source>High</source>
        <translation>Çok</translation>
    </message>
    <message>
        <source>Very High</source>
        <translation>Daha Çok</translation>
    </message>
    <message>
        <source>Language:</source>
        <translation>Dil:</translation>
    </message>
    <message>
        <source>Word Length:</source>
        <translation>Kelime Uzunluğu:</translation>
    </message>
    <message>
        <source>Amount of Words:</source>
        <translation>Kelime Miktarı:</translation>
    </message>
    <message numerus="yes">
        <source>%n letter(s)</source>
        <translation>
            <numerusform>%n kelime</numerusform>
        </translation>
    </message>
</context>
<context>
    <name>RingsPattern</name>
    <message>
        <source>Rings</source>
        <translation>Halka</translation>
    </message>
</context>
<context>
    <name>ScoresDialog</name>
    <message>
        <source>High Scores</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Rank</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Name</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Score</source>
        <translation>Skor</translation>
    </message>
    <message>
        <source>Time</source>
        <translation>Süre</translation>
    </message>
    <message>
        <source>Words</source>
        <translation>Kelime</translation>
    </message>
    <message>
        <source>Length</source>
        <translation>Uzunluk</translation>
    </message>
    <message>
        <source>#%1</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Congratulations!</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>You beat your top score!</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Well done!</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>You have a new high score!</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>StairsPattern</name>
    <message>
        <source>Stairs</source>
        <translation>Merdiven</translation>
    </message>
</context>
<context>
    <name>TwistyPattern</name>
    <message>
        <source>Twisty</source>
        <translation>Kıvrımlı</translation>
    </message>
</context>
<context>
    <name>WavePattern</name>
    <message>
        <source>Wave</source>
        <translation>Dalga</translation>
    </message>
</context>
<context>
    <name>Window</name>
    <message>
        <source>Success</source>
        <translation>Başarılı</translation>
    </message>
    <message>
        <source>Loading</source>
        <translation>Yükleniyor</translation>
    </message>
    <message>
        <source>Paused</source>
        <translation>Duraklatıldı</translation>
    </message>
    <message>
        <source>Definitions</source>
        <translation>Anlamlar</translation>
    </message>
    <message>
        <source>Hint</source>
        <translation>İpucu</translation>
    </message>
    <message>
        <source>&amp;Game</source>
        <translation>&amp;Oyun</translation>
    </message>
    <message>
        <source>&amp;New</source>
        <translation>&amp;Yeni</translation>
    </message>
    <message>
        <source>&amp;Choose...</source>
        <translation>S&amp;eç...</translation>
    </message>
    <message>
        <source>&amp;Details</source>
        <translation>&amp;Ayrıntılar</translation>
    </message>
    <message>
        <source>&amp;Pause</source>
        <translation>&amp;Duraklat</translation>
    </message>
    <message>
        <source>P</source>
        <translation>P</translation>
    </message>
    <message>
        <source>&amp;Hint</source>
        <translation>&amp;İpucu</translation>
    </message>
    <message>
        <source>H</source>
        <translation>H</translation>
    </message>
    <message>
        <source>D&amp;efinitions</source>
        <translation>A&amp;nlamlar</translation>
    </message>
    <message>
        <source>D</source>
        <translation>D</translation>
    </message>
    <message>
        <source>High &amp;Scores</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Ctrl+H</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;Quit</source>
        <translation>&amp;Çık</translation>
    </message>
    <message>
        <source>&amp;Settings</source>
        <translation>&amp;Ayarlar</translation>
    </message>
    <message>
        <source>&amp;Dark Mode</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Application &amp;Language...</source>
        <translation>Uygulama &amp;Dili</translation>
    </message>
    <message>
        <source>&amp;Help</source>
        <translation>&amp;Yardım</translation>
    </message>
    <message>
        <source>&amp;About</source>
        <translation>&amp;Hakkında</translation>
    </message>
    <message>
        <source>About &amp;Qt</source>
        <translation>&amp;Qt Hakkında</translation>
    </message>
    <message>
        <source>Choose Game</source>
        <translation>Oyun Seç</translation>
    </message>
    <message>
        <source>Game Number:</source>
        <translation>Oyun Numarası:</translation>
    </message>
    <message>
        <source>Sorry</source>
        <translation>Üzgünüm</translation>
    </message>
    <message>
        <source>Unable to start requested game.</source>
        <translation>Seçilen oyun başlatılamıyor.</translation>
    </message>
    <message>
        <source>About</source>
        <translation>Hakkında</translation>
    </message>
    <message>
        <source>Connectagram</source>
        <translation>Connectagram</translation>
    </message>
    <message>
        <source>A word unscrambling game</source>
        <translation>Bir kelime düzenleme oyunu</translation>
    </message>
    <message>
        <source>Copyright &amp;copy; 2009-%1 by Graeme Gott</source>
        <translation>Telif hakları saklıdır &amp;copy; 2009-%1 Graeme Gott</translation>
    </message>
    <message>
        <source>Released under the &lt;a href=&quot;http://www.gnu.org/licenses/gpl.html&quot;&gt;GPL 3&lt;/a&gt; license</source>
        <translation>&lt;a href=&quot;http://www.gnu.org/licenses/gpl.html&quot;&gt;GPL 3&lt;/a&gt; lisansı altında yayınlanmıştır</translation>
    </message>
    <message>
        <source>Definitions are from &lt;a href=&quot;http://wiktionary.org/&quot;&gt;Wiktionary&lt;/a&gt;</source>
        <translation>Anlamlar &lt;a href=&quot;http://wiktionary.org/&quot;&gt;Wiktionary&lt;/a&gt;&apos;dendir.</translation>
    </message>
    <message>
        <source>Details</source>
        <translation>Ayrıntılar</translation>
    </message>
    <message>
        <source>Pattern:</source>
        <translation>Kalıp:</translation>
    </message>
</context>
</TS>
